@@ -138,6 +138,10 @@ function paraselene_get_event(ev){
 }
 
 function paraselene_tag_set_event(dialog,tag){
+	dialog.onmousedown=function(kmouse){
+		paraselene_z_order(dialog,false);
+		return true;
+	};
 	tag.onmousedown=function(kmouse){
 		if(paraselene_move_obj)return true;
 		kmouse=paraselene_get_event(kmouse);
@@ -172,6 +176,55 @@ document.onmousemove=function(kmouse){
 	return false;
 };
 
+function paraselene_add_event(tag,kind,func){
+	if(tag.addEventListener){
+		tag.addEventListener(kind,func,false);
+	}
+	else{
+		tag.attachEvent("on"+kind,func);
+	}
+}
+
+function paraselene_kill_event(ev){
+	ev=paraselene_get_event(ev);
+	if(ev.preventDefault){
+		ev.preventDefault();
+	}
+	else{
+		ev.returnValue=false;
+	}
+}
+
+function paraselene_a_handler(id,page){
+	var tag=paraselene_get_id(id);
+	paraselene_add_event(tag,"click",function(ev){
+		if(!paraselene_agency_a(tag,page)){
+			paraselene_kill_event(ev);
+		}
+	});
+}
+
+var paraselene_form_kill=false;
+function paraselene_button_select(flag){
+	paraselene_form_kill=flag;
+	return true;
+}
+function paraselene_form_handler(id,page){
+	var tag=paraselene_get_id(id);
+	paraselene_add_event(tag,"submit",function(ev){
+		if(paraselene_form_kill)	return;
+		if(!paraselene_agency_form(tag,page)){
+			paraselene_kill_event(ev);
+		}
+	});
+}
+function paraselene_button_handler(id,flag){
+	var tag=paraselene_get_id(id);
+	paraselene_add_event(tag,"click",function(ev){
+		paraselene_button_select(flag);
+	});
+}
+
 function ParaseleneAjax(key,callback,msec,comet_f){
 	this.inteval=msec;
 	this.callback=callback;
@@ -315,6 +368,7 @@ function paraselene_remove(tag){
 }
 
 function paraselene_z_order(pop,del_f){
+	if(!pop)	return;
 	if(paraselene_modal_count>0 && del_f==false)	return;
 	var top=paraselene_popup.pop();
 	if(pop==top&&del_f){
@@ -377,7 +431,7 @@ function paraselene_back_resize(){
 	var back=paraselene_get_id("paraseleneEclipse");
 	back.style.height=y+"px";
 	back.style.width=x+"px";
-	setTimeout(paraselene_back_resize,500);
+	setTimeout(paraselene_back_resize,200);
 }
 
 function paraselene_dialog_open(dialog){
@@ -407,11 +461,13 @@ function paraselene_dialog_open(dialog){
 	var base=document.createElement("div");
 	base.id=pageid;
 	base.className="paraselenePopupBase paraseleneTopOrder";
-	base.style.background=dialog.bg;
 	base.style.zIndex=z;
+	base.style.background=dialog.bg2;
+	base.style.borderColor=dialog.border;
 
 	var head=document.createElement("div");
 	head.className="paraselenePopupHead";
+	head.style.borderColor=dialog.border;
 
 	var a=document.createElement("a");
 	a.className="paraselenePopupHead";
@@ -421,6 +477,8 @@ function paraselene_dialog_open(dialog){
 	var body=document.createElement("div");
 	body.id=dialog.id;
 	body.className="paraselenePopupBody";
+	body.style.background=dialog.bg;
+	body.style.borderColor=dialog.border;
 	body.innerHTML=dialog.body;
 
 	base.appendChild(head);
@@ -450,6 +508,7 @@ function paraselene_action(obj){
 		if(val.open){
 			paraselene_dialog_open(val.open);
 			resize_f=true;
+			if(val.open.cmd)	paraselene_exec(val.open.cmd);
 			continue;
 		}
 		if(val.close){
@@ -476,20 +535,25 @@ function paraselene_action(obj){
 			var target=paraselene_get_id(update_tag.id);
 			if(target)	target.innerHTML=update_tag.body;
 			resize_f=true;
+			if(update_tag.cmd)	paraselene_exec(update_tag.cmd);
 			continue;
 		}
 		if(val.exec){
-			var exec=val.exec;
-			eval(exec.cmd);
+			paraselene_exec(val.exec.cmd);
 			continue;
 		}
 	}
 }
 
+function paraselene_exec(exec){
+	for(var i=0;i<exec.length;i++){
+		eval(exec[i]);
+	}
+}
+
 function paraselene_url_check(url,param){
 	if(!navigator.cookieEnabled)	return undefined;
 	var jsession=url.split(";jsessionid");
-	if(jsession.length>1)	return undefined;
 	url=jsession[0];
 	var url_test=url.split("?");
 	url=url_test[0];
@@ -543,6 +607,7 @@ function paraselene_agency_a(o,key){
 var paraselene_called_form;
 
 function paraselene_agency_form(o,key){
+	if(paraselene_form_kill)	return true;
 	if(paraselene_called_form){
 		return false;
 	}
@@ -595,6 +660,7 @@ function paraselene_form_comp(){
 		if(head[0])	cont=head[0].innerHTML;
 	}
 	cont+=doc.body.innerHTML;
+	if(cont.indexOf("paraselene_form_ok")>0)	return;
 	document.open();
 	document.write(cont);
 	document.close();
