@@ -4,12 +4,13 @@ import paraselene.*;
 import paraselene.supervisor.*;
 import paraselene.ajax.*;
 import java.io.*;
+import javax.servlet.http.*;
 
 /**
  * JSON非同期通信。
  */
 public abstract class Json extends #1.SuperPage implements Downloadable {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 
 	/**
 	 * クライアントの取得キーを表すパラメータ。
@@ -68,6 +69,24 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
 	public void firstOutputMain( RequestParameter req ) throws PageException{}
+
+	private class LastJson implements Serializable {
+		private static final long serialVersionUID = 2L;
+		RequestParameter	req;
+		JSON	json;
+		LastJson(){}
+		LastJson( RequestParameter r, JSON j ) {
+			req = r;
+			json = j;
+		}
+		JSON getLastJson( RequestParameter r ) {
+			if ( req.equals( r ) )	return json;
+			return null;
+		}
+	}
+
+	private static final String JSON_SESSION = "paraselene$lastJson";
+
 	/**
 	 * 出力情報の設定を行う。
 	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
@@ -76,10 +95,21 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
 	public Page outputMain( Page from, RequestParameter req ) throws PageException {
+		String[]	ua = req.getHeader( "User-Agent" );
+		if ( ua != null ) {
+			opera_f = ua[0].indexOf( "Opera" ) != -1;
+		}
+
 		data = null;
+		HttpSession	session = req.getSession();
+		LastJson	lj = (LastJson)session.getAttribute( JSON_SESSION );
+		if ( lj != null ) {
+			data = lj.getLastJson( req );
+			if ( data != null )	return this;
+		}
 		RequestItem	ajax = req.getItem( Supervisor.A_AJAX_KEY );
 		if ( ajax != null ) {
-			data = Ajax.get( req.getSession(), ajax.getValue( 0 ) );
+			data = Ajax.get( session, ajax.getValue( 0 ) );
 		}
 		else {
 			Serializable	spot = outputMain( req );
@@ -89,13 +119,10 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 			else {
 				RequestItem	item = req.getItem( KEY );
 				if ( item == null )	return this;
-				data = Ajax.get( req.getSession(), item.getValue( 0 ) );
+				data = Ajax.get( session, item.getValue( 0 ) );
 			}
 		}
-		String[]	ua = req.getHeader( "User-Agent" );
-		if ( ua != null ) {
-			opera_f = ua[0].indexOf( "Opera" ) != -1;
-		}
+		session.setAttribute( JSON_SESSION, new LastJson( req, data ) );
 		return this;
 	}
 	/**
