@@ -15,6 +15,7 @@ import paraselene.tag.*;
 import paraselene.css.*;
 import paraselene.supervisor.*;
 import paraselene.tag.form.*;
+import paraselene.ajax.data.*;
 
 
 /**
@@ -578,7 +579,10 @@ public abstract class Page implements Serializable {
 			if ( !TransactionSequencer.EXTENSION.equals( path[i].substring( path[i].length() - 3 ) ) )	continue;
 			if ( alias.length() >= path[i].length() )	continue;
 			if ( !alias.equals( path[i].substring( 0, alias.length() ) ) ) continue;
-			return path[i].substring( alias.length(), path[i].length() - 3 );
+			int	start = alias.length();
+			int	end = path[i].length() - 3;
+			if ( start < end )	return path[i].substring( start, end );
+			return "";
 		}
 		return null;
 	}
@@ -1053,7 +1057,7 @@ public abstract class Page implements Serializable {
 				try {
 					script.setAttribute(
 						new Attribute( "type", "text/javascript" ),
-						new Attribute( "src", new URIValue( "paraselene.js.na" ) )
+						new Attribute( "src", "paraselene.js.na" )
 					);
 				}
 				catch( Exception e ) {
@@ -1079,7 +1083,7 @@ public abstract class Page implements Serializable {
 					new Attribute( "id", AJAX_ADD_ID )
 				);
 				body.removeHTMLPart();
-				body.addHTMLPart( div[0],div[1] );
+				body.addHTMLPart( div[0], div[1] );
 			}
 			else	ajax_f = false;
 		}
@@ -1171,5 +1175,6 @@ public abstract class Page implements Serializable {
 	 * false:ブラウザキャッシュを許可します。
 	 */
 	public boolean isNoCache() { return false; }
+
 }
 
