@@ -19,6 +19,8 @@ public class Open extends TagData {
 	public String	page_id = null;
 	public int		base_z = 1;
 	public String	bg;
+	public String	bg2;
+	public String	border;
 	public String	title = "　";
 	public boolean	modal = false;
 	public boolean	active = false;
@@ -37,13 +39,34 @@ public class Open extends TagData {
 		return buf.toString();
 	}
 
+	private Color getColor( CSSValuable[] v ) {
+		if ( v != null ) {
+			for ( int i = 0; i < v.length; i++ ) {
+				if ( v[i] instanceof Color )	return (Color)v[i];
+			}
+		}
+		return new Color( WebColor.WHITESMOKE );
+	}
+
+	private CSSValuable[] shift( Color org, int v ) {
+		YUV	yuv = org.getYUV();
+		if ( yuv.y < 128 )	yuv.y += v;
+		else	yuv.y -= v;
+		return new CSSValuable[] { new Color( yuv ) };
+	}
+
 	public Open( Page page, boolean act_f ) {
 		super( page.getFirstTagByType( "body" ) );
 		page_id = page.getUniqueKey();
 		base_z = page.getZindex();
-		bg = toBg( page.getPopupBackGround() );
+		CSSValuable[]	st = page.getPopupBackGround();
+		Color	c = getColor( st );
+		bg = toBg( st );
+		bg2 = toBg( shift( c, 48 ) );
+		border = toBg( shift( c, 24 ) );
 		Tag	title_tag = page.getFirstTagByType( "title" );
 		if ( title_tag != null )	title = title_tag.getValueString();
+		if ( title == null )	title = "　";
 		modal = page.getPopupType() == Popup.Type.MODAL;
 		active = act_f;
 	}
