@@ -60,15 +60,13 @@ public class Selector implements Serializable {
 	public static Selector joinChild( Selector parent, Selector child, boolean direct ) {
 		Selector	ret = child;
 		if ( parent == null || child == null )	return ret;
-		synchronized( ret ) {
-			parent = parent.getEnd();
-			child = child.getStart();
-			parent.child = child;
-			parent.child_near_f = direct;
-			child.parent = parent;
-			child.parent_near_f = direct;
-			return ret.getEnd();
-		}
+		parent = parent.getEnd();
+		child = child.getStart();
+		parent.child = child;
+		parent.child_near_f = direct;
+		child.parent = parent;
+		child.parent_near_f = direct;
+		return ret.getEnd();
 	}
 
 	/**
@@ -83,13 +81,11 @@ public class Selector implements Serializable {
 	public static Selector joinNext( Selector up, Selector down ) {
 		Selector	ret = down;
 		if ( up == null || down == null )	return ret;
-		synchronized( ret ) {
-			up = up.getEnd();
-			down = down.getStart();
-			up.down = down;
-			down.up = up;
-			return ret.getEnd();
-		}
+		up = up.getEnd();
+		down = down.getStart();
+		up.down = down;
+		down.up = up;
+		return ret.getEnd();
 	}
 
 	/**
@@ -101,29 +97,25 @@ public class Selector implements Serializable {
 	public static Selector joinClass( Selector main, Selector cls ) {
 		Selector	ret = main;
 		if ( main == null || cls == null )	return ret;
-		synchronized( ret ) {
-			main = main.getDefineEnd();
-			cls = cls.getDefineStart();
-			main.define_next = cls;
-			cls.define_prev = main;
-			return ret.getDefineStart();
-		}
+		main = main.getDefineEnd();
+		cls = cls.getDefineStart();
+		main.define_next = cls;
+		cls.define_prev = main;
+		return ret.getDefineStart();
 	}
 
 	public Selector getReplica() {
-		synchronized( this ) {
-			Selector	myself = new Selector( tag_name, id_name, class_name, attr.toArray( new SelectorAttribute[0] ) );
-			if ( define_next != null ) {
-				joinClass( myself, define_next.getReplica() );
-			}
-			if ( parent != null ) {
-				joinChild( parent.getReplica(), myself, parent_near_f );
-			}
-			if ( up != null ) {
-				joinNext( up.getReplica(), myself );
-			}
-			return myself;
+		Selector	myself = new Selector( tag_name, id_name, class_name, attr.toArray( new SelectorAttribute[0] ) );
+		if ( define_next != null ) {
+			joinClass( myself, define_next.getReplica() );
 		}
+		if ( parent != null ) {
+			joinChild( parent.getReplica(), myself, parent_near_f );
+		}
+		if ( up != null ) {
+			joinNext( up.getReplica(), myself );
+		}
+		return myself;
 	}
 
 	private StringBuilder toStringBuilder( StringBuilder buf ) {
