@@ -31,12 +31,10 @@ public class Style extends HTMLPart implements AttributeValuable {
 
 	public void setAssignedTag( Tag t ) {
 		super.setAssignedTag( t );
-		synchronized( this ) {
-			if ( prop == null )	return;
-			int cnt = prop.size();
-			for ( int i = 0; i < cnt; i++ ) {
-				prop.get( i ).setAssignedTag( t );
-			}
+		if ( prop == null )	return;
+		int cnt = prop.size();
+		for ( int i = 0; i < cnt; i++ ) {
+			prop.get( i ).setAssignedTag( t );
 		}
 	}
 
@@ -44,7 +42,7 @@ public class Style extends HTMLPart implements AttributeValuable {
 		return (HTMLPart)getValuableReplica();
 	}
 
-	public synchronized Valuable getValuableReplica() {
+	public Valuable getValuableReplica() {
 		int	cnt = prop.size();
 		Property[]	p = new Property[cnt];
 		for ( int i = 0; i < cnt; i++ ) {
@@ -65,7 +63,7 @@ public class Style extends HTMLPart implements AttributeValuable {
 	 * セレクタの設定。
 	 * @param s セレクタ。
 	 */
-	public synchronized void setSelector( Selector ... s ) {
+	public void setSelector( Selector ... s ) {
 		for ( int i = 0; i < s.length; i++ ) {
 			selector.add( s[i] );
 		}
@@ -76,7 +74,7 @@ public class Style extends HTMLPart implements AttributeValuable {
 	 * 属性の設定。同じ属性があると上書きされます。
 	 * @param p 属性。
 	 */
-	public synchronized void setProperty( Property ... p ) {
+	public void setProperty( Property ... p ) {
 		for ( int i = 0; i < p.length; i++ ) {
 			prop.add( p[i] );
 			prop.remove( map.put( p[i].getName(), p[i] ) );
@@ -88,7 +86,7 @@ public class Style extends HTMLPart implements AttributeValuable {
 	 * 属性の削除。
 	 * @param name 属性名。
 	 */
-	public synchronized void removeProperty( String name ) {
+	public void removeProperty( String name ) {
 		prop.remove( map.remove( name ) );
 		getAssignedTag().setModify();
 	}
@@ -97,14 +95,14 @@ public class Style extends HTMLPart implements AttributeValuable {
 	 * 属性の取得。
 	 * @param name 属性名。
 	 */
-	public synchronized Property getProperty( String name ) {
+	public Property getProperty( String name ) {
 		return map.get( name );
 	}
 
 	/**
 	 * 属性の全取得。属性の宣言順にソートされています。
 	 */
-	public synchronized Property[] getAllProperty() {
+	public Property[] getAllProperty() {
 		return prop.toArray( new Property[0] );
 	}
 
