@@ -29,8 +29,25 @@ class InStream extends ByteArrayInputStream {
 	InStream( File f ) throws FileNotFoundException, IOException {
 		super( new byte[(int)f.length()] );
 		FileInputStream	fis = new FileInputStream( f );
-		fis.read( buf );
-		fis.close();
+		try {
+			fis.read( buf );
+			bom();
+		}
+		catch( IOException e ) {
+			throw e;
+		}
+		finally {
+			fis.close();
+		}
+	}
+
+	InStream( byte[] buf ) {
+		super( buf );
+		bom();
+	}
+
+	void reload() {
+		pos = 0;
 		bom();
 	}
 }
