@@ -15,6 +15,15 @@ import paraselene.tag.*;
 import paraselene.supervisor.*;
 import paraselene.dyna.*;
 
+class FunctionInfo {
+	String	class_name;
+	String	func_name;
+	FunctionInfo( String c, String f ){
+		class_name = c;
+		func_name = f;
+	}
+}
+
 /**
  * 解析後バッファ。
  */
@@ -38,6 +47,9 @@ public class PrePage extends DynamicPage implements OutputNo {
 		}
 	}
 
+	private ArrayList<TableSource>	table = new ArrayList<TableSource>();
+
+
 	// 出力タイプ 0:view 1:logic
 	static String[] out_dir = { "view", "logic" };
 	static void setDir( String v, String l ) {
@@ -56,8 +68,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 	private HashMap<String,Integer>	method = new HashMap<String,Integer>();
 
-	private StringBuilder toName( String tag, String name ) {
-		StringBuilder	buf = new StringBuilder( " get" );
+	private FunctionInfo makeFunctionInfo( String cls, String tag, String name ) {
+		StringBuilder	buf = new StringBuilder( "get" );
 		String[]	part = name.split( "[\\p{Punct}\\p{Space}]+" );
 		for ( int i = 0; i < part.length; i++ ) {
 			if ( part[i].length() == 0 ) {
@@ -78,13 +90,20 @@ public class PrePage extends DynamicPage implements OutputNo {
 			buf = buf.append( cnt );
 			addNote( "警告: " + name + " に類似するメソッドを作成しました。" );
 		}
+		return new FunctionInfo( cls, buf.toString() );
+	}
+
+	private StringBuilder toName( FunctionInfo info ) {
+		StringBuilder	buf = new StringBuilder( " " );
+		buf = buf.append( info.func_name );
 		return buf.append( "() {\n" );
 	}
 
-	private StringBuilder getCom( String name, TagSource t ) {
+	static StringBuilder getCom( String name, String note, TagSource t ) {
 		StringBuilder	buf = new StringBuilder( "/**\n" );
 		buf = buf.append( " * " );
 		buf = buf.append( name );
+		if ( note != null )	buf = buf.append( note );
 		buf = buf.append( "." );
 		if ( t != null ) {
 			buf = buf.append( "\n" );
@@ -95,17 +114,27 @@ public class PrePage extends DynamicPage implements OutputNo {
 	}
 
 	private StringBuilder getMethod( String name, Tag t ) throws TagException {
-		StringBuilder	buf = getCom( name, (TagSource)t );
+		StringBuilder	buf = getCom( name, null, (TagSource)t );
 		String	cls = TagMap.getClassString( t );
 		buf = buf.append( cls );
-		buf = buf.append( toName( t.getName(), name ) );
+		FunctionInfo	info = makeFunctionInfo( cls, t.getName(), name );
+		buf = buf.append( toName( info ) );
 		buf = buf.append( "return (" );
 		buf = buf.append( cls );
 		buf = buf.append( ")getTag( \"" );
 		buf = buf.append( name );
-		return buf.append( "\" );\n}\n" );
+		buf = buf.append( "\" );\n}\n" );
+		int	cnt = table.size();
+		for ( int i = 0; i < cnt; i++ ) {
+			TableSource	tb = table.get( i );
+			boolean	f = getAllTag( tb.getAttributeToString( "name" ) ).length == 1;
+			buf = buf.append( tb.getOneAccesser( info, name, f ) );
+		}
+		return buf;
 	}
 
+	private static final String TAG_ARRAY = TagMap.TAG + "[]";
+
 	private StringBuilder getMethod( String name ) throws TagException {
 		Tag[]	t = getAllTag( name );
 		ArrayList<Tag>	left_tag = new ArrayList<Tag>();
@@ -119,10 +148,10 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 		if ( t.length == 1 )	buf = buf.append( getMethod( name, t[0] ) );
 		else	addNote( "name=" + name + "のタグは配列化されました。" );
-		buf = buf.append( getCom( name, null ) );
-		buf = buf.append( TagMap.TAG );
-		buf = buf.append( "[]" );
-		buf = buf.append( toName( "Tags", name ) );
+		buf = buf.append( getCom( name, null, null ) );
+		buf = buf.append( TAG_ARRAY );
+		FunctionInfo	info = makeFunctionInfo( TAG_ARRAY, "Tags", name );
+		buf = buf.append( toName( info ) );
 		buf = buf.append( "return getAllTag( \"" );
 		buf = buf.append( name );
 		return buf.append( "\" );\n}\n" );
@@ -166,6 +195,12 @@ public class PrePage extends DynamicPage implements OutputNo {
 		case 7:
 			{
 				StringBuilder	buf = new StringBuilder();
+				int	cnt = table.size();
+				for ( int i = 0; i < cnt; i++ ) {
+					TableSource	tb = table.get( i );
+					boolean	f = getAllTag( tb.getAttributeToString( "name" ) ).length == 1;
+					buf = buf.append( tb.getEnum( f ) );
+				}
 				String[]	name = getDefineNameIndex();
 				for ( int i = 0; i < name.length; i++ ) {
 					try {
@@ -341,19 +376,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 			enum_name = "";
 		}
 
-		class_name = tmp.getName().toLowerCase( Locale.ENGLISH );
-		String[]	part = class_name.split( "[\\p{Punct}\\p{Space}]+" );
-		StringBuilder	buf = new StringBuilder();
-		for ( int i = 0; i < part.length; i++ ) {
-			ch = part[i].toCharArray();
-			ch[0] = Character.toUpperCase( ch[0] );
-			buf = buf.append( new String( ch ) );
-		}
-		class_name = buf.toString();
+		class_name = name2CamelCase( tmp.getName() );
 
-		buf = new StringBuilder( enum_name );
+		StringBuilder	buf = new StringBuilder( enum_name );
 		enum_name = tmp.getName().toUpperCase();
-		part = enum_name.split( "[\\p{Punct}\\p{Space}]+" );
+		String[]	part = enum_name.split( "[\\p{Punct}\\p{Space}]+" );
 		for ( int i = 0; i < part.length; i++ ) {
 			if ( i > 0 )	buf = buf.append( "_" );
 			buf = buf.append( part[i] );
@@ -381,6 +408,18 @@ public class PrePage extends DynamicPage implements OutputNo {
 		hash_map.put( id, this );
 	}
 
+	static String name2CamelCase( String str ) {
+		String	name = str.trim().toLowerCase( Locale.ENGLISH );
+		String[]	part = name.split( "[\\p{Punct}\\p{Space}]+" );
+		StringBuilder	buf = new StringBuilder();
+		for ( int i = 0; i < part.length; i++ ) {
+			char[]	ch = part[i].toCharArray();
+			ch[0] = Character.toUpperCase( ch[0] );
+			buf = buf.append( new String( ch ) );
+		}
+		return buf.toString();
+	}
+
 	protected DynamicPage makePage() {
 		return new PrePage( this );
 	}
@@ -445,7 +484,14 @@ public class PrePage extends DynamicPage implements OutputNo {
 	}
 
 	protected Tag makeTag( String name, ArrayList<Attribute> attr ) throws Exception {
-		TagSource	nt = new TagSource( name, isSimpleTag( name ) );
+		TagSource	nt = null;
+		if ( name.equalsIgnoreCase( "table" ) ) {
+			nt = new TableSource();
+			table.add( (TableSource)nt );
+		}
+		else {
+			nt = new TagSource( name, isSimpleTag( name ) );
+		}
 		int	cnt = attr.size();
 		for ( int i = 0; i < cnt; i++ ) {
 			nt.setAttribute( attr.get( i ) );
@@ -453,6 +499,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return nt;
 	}
 
+	public void clear() {
+		super.clear();
+		table.clear();
+	}
+
 	protected Text makeText( String str ) {
 		return new TextSource( str );
 	}
