@@ -14,7 +14,7 @@ import paraselene.*;
  */
 public class JavaScript extends Feedback {
 	private static final long serialVersionUID = 2L;
-	String	cmd;
+	String[]	cmd;
 
 	private JavaScript(){}
 	/**
@@ -23,14 +23,17 @@ public class JavaScript extends Feedback {
 	 * 例えば、&quot;alert('エラーです');&quot;のように指定します。
 	 * JavaScript関数の戻り値をサーバー側で受け取る事はできません。
 	 */
-	public JavaScript( String script ) {
+	public JavaScript( String ... script ) {
 		super();
 		cmd = script;
 	}
 
 	public String toString() {
 		StringBuilder	buf = new StringBuilder( "JavaScript:" );
-		buf = buf.append( cmd );
+		for ( int i = 0; i < cmd.length; i++ ) {
+			buf = buf.append( cmd[i] );
+			buf = buf.append( " / " );
+		}
 		return buf.toString();
 	}
 
