@@ -39,6 +39,18 @@ public class Popup extends Forward implements AjaxForward {
 	public Popup( PageID id, Type dialog_type ) {
 		super( id );
 		type = dialog_type;
+		History	hist = SandBox.getCurrentRequestParameter().getHistory();
+		if ( hist != null ) {
+			Page[]	page = hist.getBrowsingPage();
+			Popup.Type	ptype = Popup.Type.MODELESS;
+			for ( int i = 0; i < page.length; i++ ) {
+				if ( page[i].getPopupType() == Popup.Type.MODAL ) {
+					ptype = Popup.Type.MODAL;
+					break;
+				}
+			}
+			overwriteType( ptype );
+		}
 	}
 
 	/**
@@ -51,7 +63,22 @@ public class Popup extends Forward implements AjaxForward {
 		active_page = page;
 	}
 
+	Page getPage( Page from ) {
+		if ( active_page != null ) {
+			Option.trace( "Popup#getPage -> %s", active_page.getUniqueKey() );
+			return active_page;
+		}
+		if ( out_page == null ) {
+			Option.trace( "Popup#getPage -> null" );
+			return null;
+		}
+		Page	p = out_page.getPageFactory().getPage( out_page.getID() );
+		Option.trace( "Popup#getPage -> %s", p.getUniqueKey() );
+		return p;
+	}
+
 	void overwriteType( Type t ) {
+		if ( type == null )	return;
 		if ( t == Type.MODELESS )	return;
 		type = t;
 	}
@@ -84,5 +111,10 @@ public class Popup extends Forward implements AjaxForward {
 		}
 		return buf.toString();
 	}
+
+	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+		Option.trace( "new OpenOutput <- %s", this );
+		return new OpenOutput( nk, lp, this, getType(), r, sd );
+	}
 }
 
