@@ -15,7 +15,8 @@ import javax.servlet.http.*;
 /**
  * リクエスト。
  */
-public class RequestParameter {
+public class RequestParameter implements Serializable {
+	private static final long serialVersionUID = 2L;
 	/**
 	 * 呼び出しリクエストメソッド。
 	 */
@@ -145,6 +146,42 @@ public class RequestParameter {
 	private Supervisor	supervisor = null;
 	static final String UA_HEAD = "User-Agent";
 
+	/**
+	 * リクエスト内容の比較。
+	 * @param o 比較対象。
+	 * @return true:同一リクエスト、false:異なるリクエスト。
+	 */
+	public boolean equals( Object o ) {
+		if ( !(o instanceof RequestParameter) )	return false;
+		RequestParameter	r = (RequestParameter)o;
+		if ( !uri.equals( r.uri ) )	return false;
+		HashMap<String,RequestItem>	ok = new HashMap<String,RequestItem>();
+		for ( String k : item_map.keySet() ) {
+			RequestItem	my_item = item_map.get( k );
+			RequestItem	ot_item = r.item_map.get( k );
+			if ( !my_item.equals( ot_item ) )	return false;
+			ok.put( k, my_item );
+		}
+		for ( String k : r.item_map.keySet() ) {
+			if ( ok.get( k ) == null )	return false;
+		}
+		HashMap<String,String[]>	ok2 = new HashMap<String,String[]>();
+		for ( String k : header.keySet() ) {
+			String[]	my_head = header.get( k );
+			String[]	ot_head = r.header.get( k );
+			if ( ot_head == null )	return false;
+			if ( my_head.length != ot_head.length )	return false;
+			for ( int i = 0; i < my_head.length; i++ ) {
+				if ( !my_head[i].equals( ot_head[i] ) )	return false;
+			}
+			ok2.put( k, my_head );
+		}
+		for ( String k : r.header.keySet() ) {
+			if ( ok2.get( k ) == null )	return false;
+		}
+		return true;
+	}
+
 	/**
 	 * ユーザーエージェントから、携帯キャリアを判定する。
 	 * @return 判定結果。
@@ -298,6 +335,15 @@ public class RequestParameter {
 		return supervisor;
 	}
 
+	/**
+	 * リクエストヘッダ名の一覧の取得。
+	 * getHeader でアクセス可能なヘッダ名の一覧です。
+	 * @return リクエストヘッダ名一覧。
+	 */
+	public String[] getHeaderNames() {
+		return header.keySet().toArray( new String[0] );
+	}
+
 	/**
 	 * リクエストヘッダの取得。複数行存在すれば複数個の配列となります。
 	 * 戻り値の配列はカンマで区切りません。行による配列です。
