@@ -43,12 +43,17 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private HashMap<PageID, RedirectData>	pending = new HashMap<PageID, RedirectData>();
 	private volatile int client;
 
+	private String cut( String org, int len ) {
+		if ( org == null )	return null;
+		int	org_len = org.length();
+		if ( org_len < len )	len = org_len;
+		return org.substring( 0, len );
+	}
+
 	private int getClient( HttpServletRequest req ) {
 		String[]	data = new String[] {
-			req.getHeader( RequestParameter.UA_HEAD ),
-			req.getHeader( "HTTP-Client-IP" ),
-			req.getHeader( "X-Forwarded-For" ),
-			req.getHeader( "Remote-Addr" )
+			cut( req.getHeader( RequestParameter.UA_HEAD ), 80 ),
+			req.getRemoteAddr()
 		};
 		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < data.length; i++ ) {
@@ -56,7 +61,9 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 			buf = buf.append( "*" );
 			buf = buf.append( data[i] );
 		}
-		return buf.toString().hashCode();
+		String	str = buf.toString();
+		Option.trace( str );
+		return str.hashCode();
 	}
 
 	SessionData( HttpServletRequest req ) {
