@@ -266,12 +266,9 @@ public abstract class Supervisor extends HttpServlet {
 			e = pe.get();
 		}
 		Forward fw = new Forward( status );
-		e.printStackTrace();
+		Option.debug( e );
 		onError( e );
 		try {
-			if ( !Option.isReleaseMode() ) {
-				Option.debug( e );
-			}
 			fw.Action( this, res );
 		}
 		catch( Throwable e2 ) {
@@ -587,6 +584,33 @@ public abstract class Supervisor extends HttpServlet {
 	private static final String XHTML = "application/xhtml+xml";
 
 	void write( Page[] out_ret, boolean session_f, Forward fw, DataHolder holder ) throws Exception {
+		try {
+			writeWork( out_ret, session_f, fw, holder );
+		}
+		catch( Exception e ) {
+			String[]	name = getClass().getName().split( "\\." );
+			StringBuilder	buf = new StringBuilder();
+			int	cnt = name.length - 1;
+			for ( int i = 0; i < cnt; i++ ) {
+				buf = buf.append( name[i] );
+				buf = buf.append( "." );
+			}
+			String	p_name = buf.toString();
+			StackTraceElement[]	st = e.getStackTrace();
+			boolean	flag = false;
+			for ( int i = 0; i < st.length; i++ ) {
+				if ( !st[i].getMethodName().equals( "getInputStream" ) )	continue;
+				if ( st[i].getClassName().indexOf( p_name ) != 0 )	continue;
+				flag = true;
+				break;
+			}
+			if ( flag )	throw e;
+			Option.debug( e );
+			Option.trace( "write error %s", e.toString() );
+		}
+	}
+
+	private void writeWork( Page[] out_ret, boolean session_f, Forward fw, DataHolder holder ) throws Exception {
 		SessionData data = holder.data;
 		HttpServletResponse	res = holder.response;
 		Page	next_page = out_ret[0];
@@ -645,8 +669,7 @@ public abstract class Supervisor extends HttpServlet {
 			if ( mod != null && date != null ) {
 				try {
 					if ( date.compareTo( new HTTPDate( mod[0] ) ) <= 0 ) {
-						res.sendError( 304 );
-						res.setContentType( mime );
+						res.setStatus( 304 );
 						data.hist.get( next_page.getHistoryKey() ).add( next_page );
 						return;
 					}
@@ -696,7 +719,14 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			else {
 				PrintWriter	w = res.getWriter();
-				out_ret[1].write( w );
+				History	h = data.hist.get( out_ret[1].getHistoryKey() );
+				try {
+					h.lock();
+					out_ret[1].write( w );
+				}
+				finally{
+					h.unlock();
+				}
 				w.flush();
 			}
 		}
