@@ -27,22 +27,26 @@ public class Anchor extends Tag {
 		return new Anchor();
 	}
 
-	private static final String ON_CLICK = "return paraselene_agency_a(this,'%s');";
-
 	public void write( PrintWriter w, StringMode mode ) {
+		setHTTPAjaxHandler( "href", "onclick", "return paraselene_agency_a(this,'%s');" );
+		super.write( w, mode );
+
+/*
 		Page	page = getAssignedPage();
-		if ( page.isAjax() ) {
+		String	id = getIDAttribute();
+		if ( page.isAjax() && isAjaxEnable() && id != null ) {
 			Attribute	attr = getAttribute( "href" );
 			if ( attr != null && getAttribute( "target" ) == null && getAttribute( "onclick" ) == null ) {
 				URIValue	v = (URIValue)attr.get();
 				if ( v != null ) {
 					if ( v.isParaselenePagePath() ) {
-						setAttribute( new Attribute( "onclick", String.format( ON_CLICK, page.getUniqueKey() ) ) );
+						String	cmd = String.format( "paraselene_a_handler('%s','%s');", id, page.getUniqueKey() );
+						page.addOnLoadScript( w, cmd );
 					}
 				}
 			}
 		}
-		super.write( w, mode );
+*/
 	}
 }
 
