@@ -26,9 +26,9 @@ public interface AttributeValuable extends Valuable {
 	Valuable getValuableReplica();
 
 	/**
-	 * 所属ページの設定。
-	 * @param p ページ。
+	 * 所属先タグの設定。
+	 * @param t 所属先。
 	 */
-	void setPage( Page p );
+	void setAssignedTag( Tag t );
 }
 
