@@ -45,6 +45,30 @@ public class Tag extends HTMLPart {
 	private static String	VALUE = "value";
 
 	private Page	embed_page = null_page;
+	private boolean	ajax_f = true;
+
+	/**
+	 * Ajax有効設定。初期値は true になっています。<br>
+	 * false を設定すると、Page が Ajax化されていても該当タグからは
+	 * Ajax 通信を行いません。<br>
+	 * この設定で効果があるのは、以下のクラスのみです。<ul>
+	 * <li>Anchor
+	 * <li>Button
+	 * <li>Form
+	 * </ul>
+	 * @param flag true:Ajax有効、false:Ajax無効。
+	 */
+	public void setAjaxEnable( boolean flag ) {
+		ajax_f = flag;
+	}
+
+	/**
+	 * Ajax有効設定の取得。
+	 * @return true:Ajax有効、false:Ajax無効。
+	 */
+	public boolean isAjaxEnable() {
+		return ajax_f;
+	}
 
 	/**
 	 * 所属先ページの取得。
@@ -191,7 +215,12 @@ public class Tag extends HTMLPart {
 	private static volatile short tag_id;
 	private static final String PARASELENE_ID = "paraselene$id$";
 
-	private void makeID() {
+	/**
+	 * ユニークIDの設定。
+	 * このタグに重複しないID属性を設定します。<br>
+	 * ただし、既にID属性も持っている場合は何もしません。
+	 */
+	public void makeID() {
 		if ( getAttribute( "id" ) != null )	return;
 		if ( "head".equals( getName() ) )	return;
 		long	now = 0;
@@ -206,6 +235,16 @@ public class Tag extends HTMLPart {
 		setAttribute( new Attribute( "id", buf.toString() ) );
 	}
 
+	/**
+	 * id属性の取得。
+	 * @return id属性に設定されているID。
+	 */
+	public String getIDAttribute() {
+		Attribute	attr = getAttribute( "id" );
+		if ( attr == null )	return null;
+		return attr.getString();
+	}
+
 	/**
 	 * コンストラクタ。
 	 * @param n タグ名。
@@ -1103,5 +1142,24 @@ public class Tag extends HTMLPart {
 		return null;
 	}
 
+	protected void setAjaxHandler( String triger, String function, Object ... param ) {
+		Page	page = getAssignedPage();
+		if ( !page.isAjax() )	return;
+		Attribute	attr = getAttribute( triger );
+		if ( attr != null )	return;
+		setAttribute( new Attribute( triger, String.format( function, (Object[])param ) ) );
+	}
+
+	protected void setHTTPAjaxHandler( String url_attr, String triger, String function ) {
+		if ( !isAjaxEnable() || getAttribute( "target" ) != null )	return;
+		Attribute	attr = getAttribute( url_attr );
+		if ( attr == null )	return;
+		URIValue	v = (URIValue)attr.get();
+		if ( v == null )	return;
+		if ( v.isParaselenePagePath() ) {
+			setAjaxHandler( triger, function, getAssignedPage().getUniqueKey() );
+		}
+	}
+
 }
 
