@@ -7,6 +7,8 @@
 package paraselene.tag.form;
 
 
+import java.io.*;
+import paraselene.*;
 import paraselene.tag.*;
 
 /**
@@ -73,5 +75,18 @@ public class Button extends Input {
 	public boolean isClicked() {
 		return pushed;
 	}
+
+	public void write( PrintWriter w, StringMode mode ) {
+		setAjaxHandler( "onclick", "return paraselene_button_select(%s);", isAjaxEnable()?	"false":	"true" );
+		super.write( w, mode );
+/*
+		Page	page = getAssignedPage();
+		String	id = getIDAttribute();
+		if ( page.isAjax() && id != null ) {
+			String	cmd = String.format( "paraselene_button_handler('%s',%s);", id, isAjaxEnable()?	"false":	"true" );
+			page.addOnLoadScript( w, cmd );
+		}
+*/
+	}
 }
 
