@@ -103,23 +103,26 @@ public class Form extends Tag {
 		super.addHTMLPart( idx, d );
 	}
 
-	private static final String ON_SUBMIT = "return paraselene_agency_form(this,'%s');";
-
 	public void write( PrintWriter w, StringMode mode ) {
+		setHTTPAjaxHandler( "action", "onsubmit", "return paraselene_agency_form(this,'%s');" );
+		dummy.setValueString( form_seq.getSeq() );
+		super.write( w, mode );
+/*
 		Page	page = getAssignedPage();
-		if ( page.isAjax() ) {
+		String	id = getIDAttribute();
+		if ( page.isAjax() && isAjaxEnable() && id != null ) {
 			Attribute	attr = getAttribute( "action" );
 			if ( attr != null && getAttribute( "target" ) == null && getAttribute( "onsubmit" ) == null ) {
 				URIValue	v = (URIValue)attr.get();
 				if ( v != null ) {
 					if ( v.isParaselenePagePath() ) {
-						setAttribute( new Attribute( "onsubmit", String.format( ON_SUBMIT, page.getUniqueKey() ) ) );
+						String  cmd = String.format( "paraselene_form_handler('%s','%s');", id, page.getUniqueKey() );
+						page.addOnLoadScript( w, cmd );
 					}
 				}
 			}
 		}
-		dummy.setValueString( form_seq.getSeq() );
-		super.write( w, mode );
+*/
 	}
 
 	protected Tag newReplica() {
